@@ -1,7 +1,7 @@
 // qjackctl.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2011, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2013, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -95,12 +95,12 @@ public:
 			} else {
 				delete m_pQtTranslator;
 				m_pQtTranslator = 0;
-		#ifdef CONFIG_DEBUG
+			#ifdef CONFIG_DEBUG
 				qWarning("Warning: no translation found for '%s' locale: %s/%s.qm",
 					loc.name().toUtf8().constData(),
 					sLocPath.toUtf8().constData(),
 					sLocName.toUtf8().constData());
-		#endif
+			#endif
 			}
 			// Try own application translation...
 			m_pMyTranslator = new QTranslator(this);
@@ -114,12 +114,12 @@ public:
 				} else {
 					delete m_pMyTranslator;
 					m_pMyTranslator = 0;
-		#ifdef CONFIG_DEBUG
+				#ifdef CONFIG_DEBUG
 					qWarning("Warning: no translation found for '%s' locale: %s/%s.qm",
 						loc.name().toUtf8().constData(),
 						sLocPath.toUtf8().constData(),
 						sLocName.toUtf8().constData());
-		#endif
+				#endif
 				}
 			}
 		}
@@ -270,8 +270,9 @@ public:
 		qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
 		if (pMainForm)
 			pMainForm->setQuitForce(true);
-
+	#if QT_VERSION < 0x050000
 		QApplication::commitData(sm);
+	#endif
 	}
 
 private:
@@ -397,6 +398,19 @@ int main ( int argc, char **argv )
 	// Dark themes grayed/disabled color group fix...
 	QPalette pal(app.palette());
 	if (pal.base().color().value() < 0x7f) {
+	#if QT_VERSION >= 0x050000
+		const QColor& color = pal.window().color();
+		const int iGroups = int(QPalette::Active | QPalette::Inactive) + 1;
+		for (int i = 0; i < iGroups; ++i) {
+			const QPalette::ColorGroup group = QPalette::ColorGroup(i);
+			pal.setBrush(group, QPalette::Light,    color.lighter(150));
+			pal.setBrush(group, QPalette::Midlight, color.lighter(120));
+			pal.setBrush(group, QPalette::Dark,     color.darker(150));
+			pal.setBrush(group, QPalette::Mid,      color.darker(120));
+			pal.setBrush(group, QPalette::Shadow,   color.darker(200));
+		}
+	//	pal.setColor(QPalette::Disabled, QPalette::ButtonText, pal.mid().color());
+	#endif
 		pal.setColorGroup(QPalette::Disabled,
 			pal.windowText().color().darker(),
 			pal.button(),
