@@ -1,7 +1,7 @@
 // qjackctlAboutForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2009, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2010, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -24,6 +24,10 @@
 
 #include <QMessageBox>
 
+#ifdef CONFIG_JACK_VERSION
+#include <jack/jack.h>
+#endif
+
 
 //----------------------------------------------------------------------------
 // qjackctlAboutForm -- UI wrapper form.
@@ -42,68 +46,68 @@ qjackctlAboutForm::qjackctlAboutForm (
     sText += "<br />\n";
     sText += tr("Version") + ": <b>" QJACKCTL_VERSION "</b><br />\n";
     sText += tr("Build") + ": " __DATE__ " " __TIME__ "<br />\n";
+#ifdef CONFIG_JACK_VERSION
+	sText += "<br />\n";
+	sText += tr("Using: JACK %1").arg(jack_get_version_string());
+	sText += "<br />\n";
+#endif
 #ifdef CONFIG_DEBUG
     sText += "<small><font color=\"red\">";
     sText += tr("Debugging option enabled.");
-    sText += "<br />\n";
-    sText += "</font></small>";
+    sText += "</font></small><br />\n";
 #endif
 #ifndef CONFIG_SYSTEM_TRAY
     sText += "<small><font color=\"red\">";
     sText += tr("System tray disabled.");
-    sText += "<br />\n";
-    sText += "</font></small>";
+    sText += "</font></small><br />\n";
 #endif
 #ifndef CONFIG_JACK_TRANSPORT
     sText += "<small><font color=\"red\">";
     sText += tr("Transport status control disabled.");
-    sText += "<br />\n";
-    sText += "</font></small>";
+    sText += "</font></small><br />\n";
 #endif
 #ifndef CONFIG_JACK_REALTIME
     sText += "<small><font color=\"red\">";
     sText += tr("Realtime status disabled.");
-    sText += "<br />\n";
-    sText += "</font></small>";
+    sText += "</font></small><br />\n";
 #endif
 #ifndef CONFIG_JACK_XRUN_DELAY
     sText += "<small><font color=\"red\">";
     sText += tr("XRUN delay status disabled.");
-    sText += "<br />\n";
-    sText += "</font></small>";
+    sText += "</font></small><br />\n";
 #endif
 #ifndef CONFIG_JACK_MAX_DELAY
     sText += "<small><font color=\"red\">";
     sText += tr("Maximum delay status disabled.");
-    sText += "<br />\n";
-    sText += "</font></small>";
-#endif
-#ifndef CONFIG_JACK_MIDI
-    sText += "<small><font color=\"red\">";
-    sText += tr("JACK MIDI support disabled.");
-    sText += "<br />\n";
-    sText += "</font></small>";
+    sText += "</font></small><br />\n";
 #endif
 #ifndef CONFIG_JACK_PORT_ALIASES
     sText += "<small><font color=\"red\">";
     sText += tr("JACK Port aliases support disabled.");
-    sText += "<br />\n";
-    sText += "</font></small>";
+    sText += "</font></small><br />\n";
+#endif
+#ifndef CONFIG_JACK_MIDI
+    sText += "<small><font color=\"red\">";
+    sText += tr("JACK MIDI support disabled.");
+    sText += "</font></small><br />\n";
+#endif
+#ifndef CONFIG_JACK_SESSION
+	sText += "<small><font color=\"red\">";
+	sText += tr("JACK Session support disabled.");
+	sText += "</font></small><br />";
 #endif
 #ifndef CONFIG_ALSA_SEQ
 #if !defined(WIN32)
     sText += "<small><font color=\"red\">";
     sText += tr("ALSA/MIDI sequencer support disabled.");
-    sText += "<br />\n";
-    sText += "</font></small>";
+    sText += "</font></small><br />\n";
 #endif
 #endif
 #ifndef CONFIG_DBUS
 #if !defined(WIN32)
     sText += "<small><font color=\"red\">";
     sText += tr("D-Bus interface support disabled.");
-    sText += "<br />\n";
-    sText += "</font></small>";
+    sText += "</font></small><br />\n";
 #endif
 #endif
     sText += "<br />\n";
