@@ -1,7 +1,7 @@
 // qjackctlAlsaConnect.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2009, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2010, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -97,14 +97,10 @@ class qjackctlAlsaClientList : public qjackctlClientList
 public:
 
 	// Constructor.
-	qjackctlAlsaClientList(qjackctlClientListView *pListView,
-		snd_seq_t *pAlsaSeq, bool bReadable);
+	qjackctlAlsaClientList(qjackctlClientListView *pListView, bool bReadable);
 	// Default destructor.
 	~qjackctlAlsaClientList();
 
-	// Alsa sequencer accessor.
-	snd_seq_t *alsaSeq() const;
-
 	// Client finder by id.
 	qjackctlAlsaClient *findClient(int iAlsaClient);
 	// Client port finder by id.
@@ -112,11 +108,6 @@ public:
 
 	// Client:port refreshner (return newest item count).
 	int updateClientPorts();
-
-private:
-
-	// Instance variables.
-	snd_seq_t *m_pAlsaSeq;
 };
 
 
@@ -128,14 +119,10 @@ class qjackctlAlsaConnect : public qjackctlConnect
 public:
 
 	// Constructor.
-	qjackctlAlsaConnect(qjackctlConnectView *pConnectView,
-		snd_seq_t *pAlsaSeq);
+	qjackctlAlsaConnect(qjackctlConnectView *pConnectView);
 	// Default destructor.
 	~qjackctlAlsaConnect();
 
-	// Alsa sequencer accessor.
-	snd_seq_t *alsaSeq() const;
-
 	// Common pixmap accessor.
 	const QPixmap& pixmap(int iPixmap) const;
 
@@ -157,9 +144,6 @@ private:
 	void createIconPixmaps();
 	void deleteIconPixmaps();
 
-	// Instance variables.
-	snd_seq_t *m_pAlsaSeq;
-
 	// Local pixmap-set array.
 	QPixmap *m_apPixmaps[QJACKCTL_ALSA_PIXMAPS];
 };
