@@ -1,7 +1,7 @@
 // qjackctlConnect.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2011, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2012, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -36,6 +36,12 @@
 #include <QDragEnterEvent>
 #include <QDragMoveEvent>
 
+#if QT_VERSION >= 0x050000
+#include <QMimeData>
+#include <QDrag>
+#endif
+
+
 //----------------------------------------------------------------------
 // class qjackctlPortItem -- Port list item.
 //
@@ -656,11 +662,17 @@ qjackctlClientListView::qjackctlClientListView (
 	m_bRenameEnabled = false;
 
 	QHeaderView *pHeader = QTreeWidget::header();
-//	pHeader->setResizeMode(QHeaderView::Custom);
 	pHeader->setDefaultAlignment(Qt::AlignLeft);
 //	pHeader->setDefaultSectionSize(120);
+#if QT_VERSION >= 0x050000
+//	pHeader->setSectionResizeMode(QHeaderView::Custom);
+	pHeader->setSectionsMovable(false);
+	pHeader->setSectionsClickable(true);
+#else
+//	pHeader->setResizeMode(QHeaderView::Custom);
 	pHeader->setMovable(false);
 	pHeader->setClickable(true);
+#endif
 	pHeader->setSortIndicatorShown(true);
 	pHeader->setStretchLastSection(true);
 
