@@ -1,7 +1,7 @@
 // qjackctlJackConnect.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2009, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2010, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -98,13 +98,10 @@ class qjackctlJackClientList : public qjackctlClientList
 public:
 
 	// Constructor.
-	qjackctlJackClientList(qjackctlClientListView *pListView, jack_client_t *pJackClient, bool bReadable);
+	qjackctlJackClientList(qjackctlClientListView *pListView, bool bReadable);
 	// Default destructor.
 	~qjackctlJackClientList();
 
-	// Jack client accessors.
-	jack_client_t *jackClient() const;
-
 	// Jack port lookup.
 	qjackctlJackPort *findJackClientPort(jack_port_t *pJackPort);
 
@@ -117,9 +114,6 @@ public:
 
 private:
 
-	// Instance variables.
-	jack_client_t *m_pJackClient;
-
 	// Jack client port aliases mode.
 	static int g_iJackClientPortAlias;
 };
@@ -133,8 +127,7 @@ class qjackctlJackConnect : public qjackctlConnect
 public:
 
 	// Constructor.
-	qjackctlJackConnect(qjackctlConnectView *pConnectView,
-		jack_client_t *pJackClient, int iJackType);
+	qjackctlJackConnect(qjackctlConnectView *pConnectView, int iJackType);
 	// Default destructor.
 	~qjackctlJackConnect();
 
