@@ -1,7 +1,7 @@
 // qjackctlPatchbay.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2010, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2012, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -39,6 +39,11 @@
 #include <QDragEnterEvent>
 #include <QDragMoveEvent>
 
+#if QT_VERSION >= 0x050000
+#include <QMimeData>
+#include <QDrag>
+#endif
+
 // Interactivity socket form.
 #include "qjackctlSocketForm.h"
 
@@ -746,11 +751,17 @@ qjackctlSocketListView::qjackctlSocketListView (
 	m_pDropItem = NULL;
 
 	QHeaderView *pHeader = QTreeWidget::header();
-//	pHeader->setResizeMode(QHeaderView::Custom);
 //	pHeader->setDefaultAlignment(Qt::AlignLeft);
 //	pHeader->setDefaultSectionSize(120);
+#if QT_VERSION >= 0x050000
+//	pHeader->setSectionResizeMode(QHeaderView::Custom);
+	pHeader->setSectionsMovable(false);
+	pHeader->setSectionsClickable(true);
+#else
+//	pHeader->setResizeMode(QHeaderView::Custom);
 	pHeader->setMovable(false);
-//	pHeader->setClickable(true);
+	pHeader->setClickable(true);
+#endif
 //	pHeader->setSortIndicatorShown(true);
 	pHeader->setStretchLastSection(true);
 
