@@ -1,7 +1,7 @@
 // qjackctlPatchbayForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2010, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2011, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -256,7 +256,7 @@ void qjackctlPatchbayForm::contentsChanged (void)
 
 
 // Refresh complete form.
-void qjackctlPatchbayForm::refreshForm ( void )
+void qjackctlPatchbayForm::refreshForm (void)
 {
 	m_pPatchbay->refresh();
 	stabilizeForm();
@@ -736,9 +736,6 @@ void qjackctlPatchbayForm::keyPressEvent ( QKeyEvent *pKeyEvent )
 		QWidget::keyPressEvent(pKeyEvent);
 		break;
 	}
-
-	// Make sure we've get focus back...
-	QWidget::setFocus();
 }
 
 
