@@ -1,7 +1,7 @@
 // qjackctlSession.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2011, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2013, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -52,6 +52,7 @@ qjackctlSession::qjackctlSession (void)
 // Destructor.
 qjackctlSession::~qjackctlSession (void)
 {
+	clearInfraClients();
 	clear();
 }
 
@@ -145,6 +146,7 @@ bool qjackctlSession::save ( const QString& sSessionDir, int iSessionType )
 
 #ifdef CONFIG_JACK_SESSION
 
+	// Second pass: get all session client commands...
 	if (jack_session_notify) {
 	
 		jack_session_event_type_t etype = JackSessionSave;
@@ -188,7 +190,30 @@ bool qjackctlSession::save ( const QString& sSessionDir, int iSessionType )
 
 #endif	// CONFIG_JACK_SESSION
 
-	// Save to file, immediate...
+	// Third pass: check whether there are registered infra-clients...
+	ClientList::ConstIterator iter = m_clients.constBegin();
+	const ClientList::ConstIterator& iter_end = m_clients.constEnd();
+
+	for ( ; iter != iter_end; ++iter) {
+		ClientItem *pClientItem = iter.value();
+		if (pClientItem->client_command.isEmpty()) {
+			const QString& sClientName = pClientItem->client_name;
+			if (sClientName == "system")
+				continue;
+			InfraClientItem *pInfraClientItem
+				= m_infra_clients.value(sClientName, NULL);
+			if (pInfraClientItem) {
+				pClientItem->client_command = pInfraClientItem->client_command;
+			} else {
+				pInfraClientItem = new InfraClientItem;
+				pInfraClientItem->client_name = sClientName;
+				pInfraClientItem->client_command = pClientItem->client_command;
+				m_infra_clients.insert(sClientName, pInfraClientItem);
+			}
+		}
+	}
+
+	// Finally: save to file, immediate...
 	return saveFile(sSessionPath + "session.xml");	
 }
 
@@ -201,25 +226,34 @@ bool qjackctlSession::load ( const QString& sSessionDir )
 		return false;
 
 	// Start/load clients...
-	int msecs = 200;
 	ClientList::ConstIterator iter = m_clients.constBegin();
-	for ( ; iter != m_clients.constEnd(); ++iter) {
-		const ClientItem *pClientItem = iter.value();
-		if (pClientItem->client_command.isEmpty())
-			continue;
-		const QString sClientDir
-			= sSessionPath + pClientItem->client_name + '/';
-		QString sCommand = pClientItem->client_command;
-		sCommand.replace("${SESSION_DIR}", sClientDir);
-		if (QProcess::startDetached(sCommand))
-			msecs += 200;
-	}
+	const ClientList::ConstIterator& iter_end = m_clients.constEnd();
 
-	// Wait a litle bit before continue...
-	QTime t;
-	t.start();
-	while (t.elapsed() < msecs)
-		QApplication::processEvents(/* QEventLoop::ExcludeUserInputEvents */);
+	for ( ; iter != iter_end; ++iter) {
+		const ClientItem *pClientItem = iter.value();
+		const QString& sClientName = pClientItem->client_name;
+		QString sCommand = pClientItem->client_command;
+		if (sCommand.isEmpty()) {
+			// Maybe a registered infra-client command...
+			InfraClientItem *pInfraClientItem
+				= m_infra_clients.value(sClientName, NULL);
+			if (pInfraClientItem && !isJackClient(sClientName))
+				sCommand = pInfraClientItem->client_command;
+		}
+		else
+		if (!pClientItem->client_uuid.isEmpty()){
+			// Sure a legit session-client command...
+			const QString& sClientDir
+				= sSessionPath + pClientItem->client_name + '/';
+			sCommand.replace("${SESSION_DIR}", sClientDir);
+		}
+		// Launch command and wait a litle bit before continue...
+		if (!sCommand.isEmpty() && QProcess::startDetached(sCommand)) {
+			QTime time; time.start();
+			while (time.elapsed() < 200)
+				QApplication::processEvents();
+		}
+	}
 
 	// Initial reconnection.
 	update();
@@ -245,7 +279,9 @@ bool qjackctlSession::update (void)
 
 	// Now, make the saved connections...
 	ClientList::ConstIterator iter = m_clients.constBegin();
-	for ( ; iter != m_clients.constEnd(); ++iter) {
+	const ClientList::ConstIterator& iter_end = m_clients.constEnd();
+
+	for ( ; iter != iter_end; ++iter) {
 		ClientItem *pClientItem = iter.value();
 		if (pClientItem->connected < 1)
 			continue;
@@ -429,8 +465,9 @@ bool qjackctlSession::saveFile ( const QString& sFilename )
 
 	// Save clients spec...
 	ClientList::ConstIterator iter = m_clients.constBegin();
+	const ClientList::ConstIterator& iter_end = m_clients.constEnd();
 
-	for (; iter != m_clients.constEnd(); ++iter) {
+	for ( ; iter != iter_end; ++iter) {
 
 		const ClientItem *pClientItem = iter.value();
 		QDomElement eClient = doc.createElement("client");
@@ -478,4 +515,98 @@ bool qjackctlSession::saveFile ( const QString& sFilename )
 }
 
 
+// Infra-client list accessor (read-only)
+qjackctlSession::InfraClientList& qjackctlSession::infra_clients (void)
+{
+	return m_infra_clients;
+}
+
+
+// Load all infra-clients from configuration file.
+void qjackctlSession::loadInfraClients ( QSettings& settings )
+{
+	clearInfraClients();
+
+	settings.beginGroup("/InfraClients");
+	const QStringList& keys = settings.childKeys();
+	QStringListIterator iter(keys);
+	while (iter.hasNext()) {
+		const QString& sKey = iter.next();
+		const QString& sValue = settings.value(sKey).toString();
+		if (!sValue.isEmpty()) {
+			InfraClientItem *pInfraClientItem = new InfraClientItem;
+			pInfraClientItem->client_name = sKey;
+			pInfraClientItem->client_command = sValue;
+			m_infra_clients.insert(sKey, pInfraClientItem);
+		}
+	}
+	settings.endGroup();
+}
+
+
+// Save all infra-clients to configuration file.
+void qjackctlSession::saveInfraClients ( QSettings& settings )
+{
+	settings.beginGroup("/InfraClients");
+	settings.remove(QString()); // Remove all current keys.
+	InfraClientList::ConstIterator iter = m_infra_clients.constBegin();
+	const InfraClientList::ConstIterator& iter_end
+		= m_infra_clients.constEnd();
+	for ( ; iter != iter_end; ++iter) {
+		const QString& sKey = iter.key();
+		const QString& sValue = iter.value()->client_command;
+		if (!sValue.isEmpty())
+			settings.setValue(sKey, sValue);
+	}
+	settings.endGroup();
+}
+
+
+// Clear infra-client table.
+void qjackctlSession::clearInfraClients (void)
+{
+	qDeleteAll(m_infra_clients);
+	m_infra_clients.clear();
+}
+
+
+// Check whether a given JACK client name exists...
+bool qjackctlSession::isJackClient ( const QString& sClientName ) const
+{
+	const QByteArray aClientName = sClientName.toUtf8();
+
+#ifdef CONFIG_JACK_SESSION
+
+	if (jack_get_uuid_for_client_name) {
+
+		qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
+		if (pMainForm == NULL)
+			return false;
+
+		jack_client_t *pJackClient = pMainForm->jackClient();
+		if (pJackClient == NULL)
+			return false;
+
+		const char *client_uuid = jack_get_uuid_for_client_name(
+			pJackClient, aClientName.constData());
+		if (client_uuid) {
+			jack_free((void *) client_uuid);
+			return true;
+		}
+
+		return false;
+	}
+#endif
+
+	jack_client_t *pJackClient = jack_client_open(aClientName.constData(),
+		jack_options_t(JackNoStartServer | JackUseExactName), NULL);
+	if (pJackClient) {
+		jack_client_close(pJackClient);
+		return true;
+	}
+
+	return false;
+}
+
+
 // end of qjackctlSession.cpp
