@@ -1,7 +1,7 @@
 // qjackctlSessionForm.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2011, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2013, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -30,6 +30,7 @@
 
 #include "ui_qjackctlSessionForm.h"
 
+#include <QItemDelegate>
 #include <QFileInfo>
 
 // Forward declarations.
@@ -38,6 +39,84 @@ class qjackctlSetup;
 
 class QMenu;
 class QIcon;
+class QLineEdit;
+class QToolButton;
+
+
+//-------------------------------------------------------------------------
+// qjackctlSessionInfraClientItemEditor
+
+class qjackctlSessionInfraClientItemEditor : public QWidget
+{
+	Q_OBJECT
+
+public:
+
+	// Constructor.
+	qjackctlSessionInfraClientItemEditor(
+		QWidget *pParent, const QModelIndex& index);
+
+	// Shortcut text accessors.
+	void setText(const QString& sText);
+	QString text() const;
+
+	// Default (initial) shortcut text accessors.
+	void setDefaultText(const QString& sDefaultText)
+		{ m_sDefaultText = sDefaultText; }
+	const QString& defaultText() const
+		{ return m_sDefaultText; }
+
+signals:
+
+	void finishSignal();
+
+protected slots:
+
+	void browseSlot();
+	void resetSlot();
+	void finishSlot();
+
+private:
+
+	// Instance variables.
+	QModelIndex m_index;
+
+	QLineEdit   *m_pItemEdit;
+	QToolButton *m_pBrowseButton;
+	QToolButton *m_pResetButton;
+
+	QString m_sDefaultText;
+};
+
+
+//-------------------------------------------------------------------------
+// qjackctlSessionInfraClientItemDelegate
+
+class qjackctlSessionInfraClientItemDelegate : public QItemDelegate
+{
+	Q_OBJECT
+
+public:
+
+	// Constructor.
+	qjackctlSessionInfraClientItemDelegate(QObject *pParent = NULL);
+
+protected:
+
+	QWidget *createEditor(QWidget *pParent,
+		const QStyleOptionViewItem& option,
+		const QModelIndex& index) const;
+
+	void setEditorData(QWidget *pEditor,
+		const QModelIndex &index) const;
+	void setModelData(QWidget *pEditor,
+		QAbstractItemModel *pModel,
+		const QModelIndex& index) const;
+
+protected slots:
+
+	void commitEditor();
+};
 
 
 //----------------------------------------------------------------------------
@@ -57,6 +136,9 @@ public:
 	// Global setup method.
 	void setup(qjackctlSetup *pSetup);
 
+	// Maybe ask whether we can close.
+	bool queryClose();
+
 	// Recent session directories and save type accessors.
 	const QStringList& sessionDirs() const;
 	bool isSaveSessionVersion() const;
@@ -87,14 +169,24 @@ protected slots:
 	void updateRecentMenu();
 	void clearRecentMenu();
 
+	void sessionViewContextMenu(const QPoint& pos);
+
+	void addInfraClient();
+	void editInfraClient();
+	void editInfraClientCommit();
+	void removeInfraClient();
+
+	void selectInfraClient();
+	void updateInfraClients();
+
+	void infraClientContextMenu(const QPoint& pos);
+
 protected:
 
 	void showEvent(QShowEvent *);
 	void hideEvent(QHideEvent *);
 	void closeEvent(QCloseEvent *);
 
-	void contextMenuEvent(QContextMenuEvent *);
-
 	void keyPressEvent(QKeyEvent *);
 
 	void saveSessionEx(int iSessionType = 0);
@@ -122,6 +214,9 @@ private:
 	// Save session menu.
 	QMenu *m_pSaveMenu;
 
+	// Setup options.
+	qjackctlSetup *m_pSetup;
+
 	// Session directory history.
 	QStringList m_sessionDirs;
 };
