@@ -1,7 +1,7 @@
 // qjackctlSocketForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2010, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2012, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -63,10 +63,15 @@ qjackctlSocketForm::qjackctlSocketForm (
 
 	// Plug list view...
 	QHeaderView *pHeader = m_ui.PlugListView->header();
-//	pHeader->setResizeMode(QHeaderView::Custom);
-	pHeader->setDefaultAlignment(Qt::AlignLeft);
+//	pHeader->setDefaultAlignment(Qt::AlignLeft);
 //	pHeader->setDefaultSectionSize(300);
+#if QT_VERSION >= 0x050000
+//	pHeader->setSectionResizeMode(QHeaderView::Custom);
+	pHeader->setSectionsMovable(false);
+#else
+//	pHeader->setResizeMode(QHeaderView::Custom);
 	pHeader->setMovable(false);
+#endif
 	pHeader->setStretchLastSection(true);
 
 #ifndef CONFIG_JACK_MIDI
